@@ -1,8 +1,6 @@
 #!/usr/bin/env python
 #coding: utf8
-
-from __future__ import with_statement
-__doc__ = """
+"""
 Reads Oxford Diffraction Sapphire 3 images
 
 Authors:
@@ -19,11 +17,14 @@ Authors:
 
 """
 
+# Get ready for python3:
+from __future__ import with_statement, print_function
+
 import time, logging, struct
 logger = logging.getLogger("OXDimage")
 import numpy
-from fabioimage import fabioimage
-from compression import decTY1, compTY1
+from .fabioimage import fabioimage
+from .compression import decTY1, compTY1
 
 try:
     from numpy import rad2deg, deg2rad
@@ -245,8 +246,8 @@ class OXDimage(fabioimage):
                 self.header[key] = DEFAULT_HEADERS[key]
 
         if "NX" not in self.header.keys() or "NY" not in self.header.keys():
-			self.header['NX'] = self.dim1
-			self.header['NY'] = self.dim2
+            self.header['NX'] = self.dim1
+            self.header['NY'] = self.dim2
         ascii_headers = [self.header['Header Version'],
                        "COMPRESSION=%s (%5.1f)" % (self.header["Compression"], self.getCompressionRatio()),
                        "NX=%4i NY=%4i OI=%7i OL=%7i " % (self.header["NX"], self.header["NY"], self.header["OI"], self.header["OL"]),
